<?php
// API doc : https://coincheck.com/ja/documents/exchange/api#order-new
// API url : https://coincheck.com/api/exchange/orders

// order ui
require("./leverage_order_ui.php");

// Please set ACCESS_KEY and SECRET_ACCESS_KEY
$ACCESS_KEY = "";
$SECRET_ACCESS_KEY = "";

// BTC/JPY only
$currency_pair = "btc_jpy";

// proxy settings
$proxy      = ""; 
$proxy_port = ""; 

// coincheck order api url
$url =  "https://coincheck.com/api/exchange/orders";
// Post data type
$json = FALSE;  // $json ? POST data is JSON : POST data is Query string

// input order
$order = leverage_order_ui();

// post data
$postdata_array = array(
	"rate" => $order["rate"],
	"amount" => $order["amount"],
	"order_type" => $order["order_type"],
	"pair" => $currency_pair);
if($json) {
    $postdata = json_encode($postdata_array);   // POST data is JSON
} else {
    $postdata = http_build_query($postdata_array);  // POST data is Query string
}

// create signature
$nonce = time();
$message = $nonce . $url . $postdata;
$signature = hash_hmac("sha256", $message, $SECRET_ACCESS_KEY);

// header
$headers = array(
    "ACCESS-KEY: {$ACCESS_KEY}",
    "ACCESS-SIGNATURE: {$signature}",
    "ACCESS-NONCE: {$nonce}",
    );
if ($json) { // $json ? POST data is JSON : POST data is Query string
    array_push($headers, "Content-Type: application/json");
}

$curl = curl_init();
if ($curl == FALSE) {
    fputs(STDERR, "[ERR] curl_init(): " . curl_error($curl) . PHP_EOL);
    die(1);
}
// set proxy server settings
if (!empty($proxy) && !empty($proxy_port)) {
    curl_setopt($curl, CURLOPT_HTTPPROXYTUNNEL, 1); 
    curl_setopt($curl, CURLOPT_PROXY, $proxy . ":" . $proxy_port);
    curl_setopt($curl, CURLOPT_PROXYPORT, $proxy_port);
}
curl_setopt($curl, CURLOPT_URL, $url);
curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
curl_setopt($curl, CURLOPT_HTTPHEADER, $headers);
curl_setopt($curl, CURLOPT_POST, true);
curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'POST');
curl_setopt($curl, CURLOPT_POSTFIELDS, $postdata);


$response = curl_exec($curl);
if ($response == FALSE) {
    fputs(STDERR, "[ERR] curl_exec(): " . curl_error($curl) . PHP_EOL);
    die(1);
}
curl_close($curl);

// json decode
$json_decode = json_decode($response, true);
if ($json_decode == NULL) {
    fputs(STDERR, "[ERR] json_decode(): " . json_last_error_msg() . PHP_EOL);
    die(1);
}

// output json_decode
print_r($json_decode);

exit(0);
